/* See LICENSE file for copyright and license details. */

#include <xkbcommon/xkbcommon-keysyms.h>

/* appearance */
static const char font[]            = "-*-terminus-medium-r-*-*-16-*-*-*-*-*-*-*";
//static const char font[]            = "-*-terminus-medium-r-normal-*-14-*-*-*-*-*-*-*";
static const char normbordercolor[] = "#ff0000";
static const char normbgcolor[]     = "#330000";
static const char normfgcolor[]     = "#ff0000";
static const char selbordercolor[]  = "#00ff00";
static const char selbgcolor[]      = "#440000";
static const char selfgcolor[]      = "#ffff00";
static const unsigned int borderpx  = 1;        /* border pixel of windows */
static const unsigned int snap      = 8;        /* snap pixel */
static unsigned int padding         = 0;
static const Bool showbar           = True;     /* False means no bar */
static const Bool topbar            = True;     /* False means bottom bar */
static unsigned char systray_spacing= 16;
static Bool systray_enable          = True;

/* tagging */
static const char *tags[] = { "1", "2", "3", "4", "5", "6", "7", "8", "9" };

static const Rule rules[] = {
	/* class      instance    title       tags mask     isfloating   is bg    monitor */
	{ "mplayer",  NULL,       NULL,       0,            True,        False,       -1 },
	{ "mpv",      NULL,       NULL,       0,            True,        False,       -1 },
	{ "Gimp",     NULL,       NULL,       0,            True,        False,       -1 },
	{ "Firefox",  NULL,       NULL,       1 << 8,       False,       False,       -1 },
};

/* layout(s) */
static const float mfact      = 0.55; /* factor of master area size [0.05..0.95] */
static const Bool resizehints = True; /* True means respect size hints in tiled resizals */

#include "bstack.c"
#include "bstackhoriz.c"
static const Layout layouts[] = {
	/* symbol     arrange function */
	{ "[]=",      tile },    /* first entry is default */
	{ "><>",      NULL },    /* no layout function means floating behavior */
	{ "[M]",      monocle },
	{ "TTT",      bstack },
	{ "===",      bstackhoriz },
};

/* key definitions */
#define MODKEY Mod1Mask
#define TAGKEYS(KEY,TAG) \
	{ MODKEY,                       KEY,      view,           {.ui = 1 << TAG} }, \
	{ MODKEY|ControlMask,           KEY,      toggleview,     {.ui = 1 << TAG} }, \
	{ MODKEY|ShiftMask,             KEY,      tag,            {.ui = 1 << TAG} }, \
	{ MODKEY|ControlMask|ShiftMask, KEY,      toggletag,      {.ui = 1 << TAG} },

/* helper for spawning shell commands in the pre dwm-5.0 fashion */
#define SHCMD(cmd) { .v = (const char*[]){ "/bin/sh", "-c", cmd, NULL } }

/* commands */
static const char *dmenucmd[] = { "_dwm_menu.sh", "-fn", font, "-nb", normbgcolor, "-nf", normfgcolor, "-sb", selbgcolor, "-sf", selfgcolor, NULL };
static const char *termcmd[]  = { "xterm", NULL };
static const char *xwwwbrowserselcmd[] = { "x-www-browser-xsel", NULL };
//static const char *itscmd[]  			= { "redmine.sh", NULL };
static const char *itsissueselcmd[] 		= { "redmine-issue-sel.sh", NULL };
static const char *itsissuedelselcmd[]  	= { "redmine-issue-del-sel.sh", NULL };
static const char *itsissuedelselconfirmcmd[] 	= { "redmine-issue-del-sel.sh", "confirm", NULL };
static const char *muteToggleCmd[] 		= { "_dwm_mute.sh", NULL };
static const char *mpvPrevCmd[] 		= { "_dwm_mpv_prev.sh", NULL };
static const char *mpvNextCmd[] 		= { "_dwm_mpv_next.sh", NULL };
static const char *mpvPlayPauseCmd[] 		= { "_dwm_mpv_playpause.sh", NULL };
static const char *mpvForwardCmd[] 		= { "_dwm_mpv_forward.sh", NULL };
static const char *mpvBackwardCmd[] 		= { "_dwm_mpv_backward.sh", NULL };
static const char *layoutEn[] 			= { "xkblayout-state", "set", "0", NULL };
static const char *layoutRu[] 			= { "xkblayout-state", "set", "1", NULL };
static const char *keyboardChangeColor[] 	= { "/usr/local/bin/_keyboard_randomFromCycle_color.sh", NULL };
//static const char *xk_XF86WebCam_cmd[] 		= { "XF86WebCam.sh", NULL };

static Key keys[] = {
	/* modifier                     key        function        argument */
//	{ 0,				XK_XF86WebCam,spawn,          {.v = xk_XF86WebCam_cmd } },
	{ MODKEY,                       XK_p,      spawn,          {.v = dmenucmd } },
	{ MODKEY|ShiftMask,             XK_w,      spawn,          {.v = xwwwbrowserselcmd } },
	{ MODKEY|ShiftMask,             XK_Return, spawn,          {.v = termcmd } },
	{ MODKEY|ShiftMask,             XK_b,      togglebar,      {0} },
	{ MODKEY,                       XK_j,      focusstack,     {.i = +1 } },
	{ MODKEY,                       XK_k,      focusstack,     {.i = -1 } },
	{ MODKEY,                       XK_h,      setmfact,       {.f = -0.05} },
	{ MODKEY,                       XK_l,      setmfact,       {.f = +0.05} },
	{ MODKEY,                       XK_Return, zoom,           {0} },
	{ MODKEY,                       XK_Tab,    view,           {0} },
	{ MODKEY|ShiftMask,             XK_c,      killclient,     {0} },
	{ MODKEY,                       XK_z,      setlayout,      {.v = &layouts[0]} },
	{ MODKEY,                       XK_x,      setlayout,      {.v = &layouts[1]} },
	{ MODKEY,                       XK_c,      setlayout,      {.v = &layouts[2]} },
	{ MODKEY,                       XK_v,      setlayout,      {.v = &layouts[3]} },
	{ MODKEY,                       XK_b,      setlayout,      {.v = &layouts[4]} },
	{ MODKEY,                       XK_space,  setlayout,      {0} },
	{ MODKEY|ShiftMask,             XK_space,  togglefloating, {0} },
	{ MODKEY|ControlMask,           XK_space,  togglebg,       {0} },
	{ MODKEY,                       XK_0,      view,           {.ui = ~0 } },
	{ MODKEY|ShiftMask,             XK_0,      tag,            {.ui = ~0 } },
	{ MODKEY,                       XK_grave,  spawn,          {.v = itsissueselcmd} },
	{ MODKEY|ShiftMask,             XK_grave,  spawn,          {.v = itsissuedelselcmd} },
	{ MODKEY|ShiftMask|ControlMask,	XK_grave,  spawn,          {.v = itsissuedelselconfirmcmd} },
	{ MODKEY,                       XK_comma,  focusmon,       {.i = +1 } },
	{ MODKEY,                       XK_period, focusmon,       {.i = -1 } },
	{ MODKEY|ShiftMask,             XK_comma,  tagmon,         {.i = +1 } },
	{ MODKEY|ShiftMask,             XK_period, tagmon,         {.i = -1 } },
	TAGKEYS(                        XK_1,                      0)
	TAGKEYS(                        XK_2,                      1)
	TAGKEYS(                        XK_3,                      2)
	TAGKEYS(                        XK_4,                      3)
	TAGKEYS(                        XK_5,                      4)
	TAGKEYS(                        XK_6,                      5)
	TAGKEYS(                        XK_7,                      6)
	TAGKEYS(                        XK_8,                      7)
	TAGKEYS(                        XK_9,                      8)
	{ MODKEY|ShiftMask,             XK_q,      quit,           {0} },
	{ 0,				XK_Super_L, spawn,         {.v = layoutEn} },
	{ ShiftMask,			XK_Super_L, spawn,         {.v = layoutRu} },
	{ 0,				XKB_KEY_XF86WWW, spawn,    {.v = layoutEn} },
	{ 0,				XKB_KEY_XF86Back, spawn,   {.v = layoutRu} },
	{ 0,				XKB_KEY_XF86AudioMute, spawn,   {.v = muteToggleCmd} },
	{ 0,				XKB_KEY_XF86AudioPrev, spawn,   {.v = mpvPrevCmd} },
	{ 0,				XKB_KEY_XF86AudioNext, spawn,   {.v = mpvNextCmd} },
	{ 0,				XKB_KEY_XF86AudioPlay, spawn,   {.v = mpvPlayPauseCmd} },
	{ 0,				XKB_KEY_XF86AudioRaiseVolume, spawn, {.v = mpvForwardCmd} },
	{ 0,				XKB_KEY_XF86AudioLowerVolume, spawn, {.v = mpvBackwardCmd} },
	{ 0,				XKB_KEY_XF86Launch0, spawn, {.v = keyboardChangeColor} },
	{ MODKEY|ControlMask,		XK_bracketright, paddingAdd, {.i = +1 } },
	{ MODKEY|ControlMask,		XK_bracketleft,  paddingAdd, {.i = -1 } },
};

/* button definitions */
/* click can be ClkLtSymbol, ClkStatusText, ClkWinTitle, ClkClientWin, or ClkRootWin */
static Button buttons[] = {
	/* click                event mask      button          function        argument */
	{ ClkLtSymbol,          0,              Button1,        setlayout,      {0} },
	{ ClkLtSymbol,          0,              Button3,        setlayout,      {.v = &layouts[2]} },
	{ ClkWinTitle,          0,              Button2,        zoom,           {0} },
	{ ClkStatusText,        0,              Button2,        spawn,          {.v = termcmd } },
	{ ClkClientWin,         MODKEY,         Button1,        movemouse,      {0} },
	{ ClkClientWin,         MODKEY,         Button2,        togglefloating, {0} },
	{ ClkClientWin,         MODKEY,         Button3,        resizemouse,    {0} },
	{ ClkTagBar,            0,              Button1,        view,           {0} },
	{ ClkTagBar,            0,              Button3,        toggleview,     {0} },
	{ ClkTagBar,            MODKEY,         Button1,        tag,            {0} },
	{ ClkTagBar,            MODKEY,         Button3,        toggletag,      {0} },
};

